import React from 'react'
import { connect } from 'react-redux'
import { Button, th } from '@pubsweet/ui'
import { actions } from 'pubsweet-client'
import styled, { css } from 'styled-components'
import { compose, withHandlers } from 'recompose'
import {
  withModal2,
  ConfirmationModal,
} from 'pubsweet-component-modal/src/components'
import { selectFetchingDecision, reviewerDecision } from '../../redux/reviewers'

const ReviewerDecision = ({ showAcceptModal, showDeclineModal, ...rest }) => (
  <div>
    <DecisionButton onClick={showDeclineModal}>Decline</DecisionButton>
    <DecisionButton onClick={showAcceptModal} primary>
      Agree
    </DecisionButton>
  </div>
)

const ModalComponent = connect(state => ({
  isFetching: selectFetchingDecision(state),
}))(({ isFetching, ...rest }) => (
  <ConfirmationModal {...rest} isFetching={isFetching} />
))

export default compose(
  connect(null, {
    reviewerDecision,
    getCollections: actions.getCollections,
  }),
  withModal2(props => ({
    modalComponent: ModalComponent,
  })),
  withHandlers({
    decisionSuccess: ({ getCollections, hideModal }) => () => {
      getCollections()
      hideModal()
    },
  }),
  withHandlers({
    showAcceptModal: ({
      project,
      showModal,
      invitation,
      decisionSuccess,
      reviewerDecision,
    }) => () => {
      showModal({
        title: 'Agree to review Manuscript?',
        confirmText: 'Agree',
        onConfirm: () => {
          reviewerDecision(invitation.id, project.id, true).then(
            decisionSuccess,
          )
        },
      })
    },
    showDeclineModal: ({
      project,
      showModal,
      invitation,
      decisionSuccess,
      reviewerDecision,
    }) => () => {
      showModal({
        title: 'Decline to review Manuscript?',
        confirmText: 'Decline',
        onConfirm: () => {
          reviewerDecision(invitation.id, project.id, false).then(
            decisionSuccess,
          )
        },
      })
    },
  }),
)(ReviewerDecision)

// #region styled-components
const defaultText = css`
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
`

const DecisionButton = styled(Button)`
  ${defaultText};
  align-items: center;
  color: ${({ primary }) =>
    primary ? th('colorTextReverse') : th('colorPrimary')});
  background-color: ${({ primary }) =>
    primary ? th('colorPrimary') : th('backgroundColorReverse')};
  height: calc(${th('subGridUnit')}*5);
  text-align: center;
`
// #endregion
